@@ -5,7 +5,7 @@ use warnings;
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.06';
+    $VERSION     = '0.08';
     @ISA         = qw(Exporter);
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw(_strip);
@@ -23,36 +23,36 @@ Net::Sieve::Script - Parse and write sieve scripts
 =head1 SYNOPSIS
 
   use Net::Sieve::Script;
-  
+
   my $test_script = 'require "fileinto";
      # Place all these in the "Test" folder
      if header :contains "Subject" "[Test]" {
 	       fileinto "Test";
      }';
-  
+
   my $script = Net::Sieve::Script->new ($test_script);
-     
+
      print "OK" if ( $script->parsing_ok ) ;
-     
+
      print $script->write_script;
 
 or
 
     my $script = Net::Sieve::Script->new();
-    
+
     my $cond = Net::Sieve::Script::Condition->new('header');
        $cond->match_type(':contains');
        $cond->header_list('"Subject"');
        $cond->key_list('"Re: Test2"');
-    
+
     my $actions = 'fileinto "INBOX.test"; stop;';
-    
+
     my $rule =  Net::Sieve::Script::Rule->new();
        $rule->add_condition($cond);
        $rule->add_action($actions);
-       
+
        $script->add_rule($rule);
-       
+
        print $script->write_script;
 
 
@@ -172,6 +172,58 @@ sub write_script {
     return $require_line.$text;
 }
 
+=head2 equals
+
+ $object->equals($test_object): return 1 if $object and $test_object are equals
+
+=cut
+
+sub equals {
+    my $self = shift;
+    my $object = shift;
+
+    return 0 unless (defined $object);
+    return 0 unless ($object->isa('Net::Sieve::Script'));
+
+    my @accessors = qw( require );
+
+    foreach my $accessor ( @accessors ) {
+        my $myvalue = $self->$accessor;
+        my $theirvalue = $object->$accessor;
+        if (defined $myvalue) {
+            return 0 unless (defined $theirvalue); 
+            return 0 unless ($myvalue eq $theirvalue);
+        } else {
+            return 0 if (defined $theirvalue);
+        }
+    }
+
+    if (defined $self->rules) {
+        my @myrules = sort { $a->priority() <=> $b->priority() } @{$self->rules()};
+        my @theirrules = sort { $a->priority() <=> $b->priority() } @{$object->rules()} ;
+        return 0 unless ($#myrules == $#theirrules);
+
+        unless ($#myrules == -1) {
+            foreach my $index (0..$#myrules) {
+                my $myrule = $myrules[$index];
+                my $theirrule = $theirrules[$index];
+                if (defined ($myrule)) {
+					return 0 unless ($myrule->isa(
+									'Net::Sieve::Script::Rule'));
+                    return 0 unless ($myrule->equals($theirrule));
+                } else {
+                    return 0 if (defined ($theirrule));
+                }
+            }
+        }
+
+    } else {
+        return 0 if (defined ($object->rules));
+    }
+	return 1;
+}
+
+
 =head2 read_rules
 
  $script->read_rules()  : read rules from raw 
@@ -281,6 +333,45 @@ sub swap_rules
     return 1;
 }
 
+=head2 reorder_rules
+
+Reorder rules with a list of number, start with 1, and with blanck separator. Usefull for ajax sort functions.
+
+Thank you jeanne for your help in brain storming.
+
+Return 1 on success, 0 on error
+
+=cut
+
+sub reorder_rules
+{
+    my $self = shift;
+    my $list = shift;
+
+	return 0 if ( ! $list );
+
+    my @swap = split ' ',$list;
+
+	return 0 if ( ! scalar @swap );
+	return 0 if ( scalar @swap != $self->max_priority );
+
+    my @new_ordered_rules;
+    foreach my $swap ( @swap ) {
+      if ($swap =~ m/\d+/) {
+       my $rule = $self->find_rule($swap);
+       push @new_ordered_rules, $rule;
+      }
+    }
+
+    my $i=1;
+    foreach my $rule (@new_ordered_rules) {
+      $rule->priority($i);
+      $i++;
+    };
+
+    return 1;
+}
+
 =head2 delete_rule
 
 Delete rule and change priority, delete rule take care for 'if' test
