@@ -1,12 +1,12 @@
 package Net::Sieve::Script::Action;
 use strict;
-#use warnings;
+use warnings;
 
 use base qw(Class::Accessor::Fast);
 
 use vars qw($VERSION);
 
-$VERSION = '0.0.5';
+$VERSION = '0.08';
 
 __PACKAGE__->mk_accessors(qw(command param));
 
@@ -36,6 +36,29 @@ sub new
     return $self;
 }
 
+sub equals {
+    my $self = shift;
+    my $object = shift;
+
+    return 0 unless (defined $object);
+    return 0 unless ($object->isa('Net::Sieve::Script::Action'));
+
+    my @accessors = qw( param command );
+
+    foreach my $accessor ( @accessors ) {
+        my $myvalue = $self->$accessor;
+        my $theirvalue = $object->$accessor;
+        if (defined $myvalue) {
+            return 0 unless (defined $theirvalue); 
+            return 0 unless ($myvalue eq $theirvalue);
+        } else {
+            return 0 if (defined $theirvalue);
+        }       
+    }
+	return 1;
+}
+
+
 =head1 NAME
 
 Net::Sieve::Script::Action - parse and write actions in sieve scripts
@@ -78,6 +101,10 @@ read param : C<< $action->param() >>
 
 set param  : C<< $action->param(' :days 3 "I am away this week."') >>
 
+=head2 equals
+
+return 1 if actions are equals
+
 =head1 AUTHOR
 
 Yves Agostini - Univ Metz - <agostini@univ-metz.fr>
